@@ -20,9 +20,9 @@ var settings;
 var attachlist = [];
 var uploadlist = [];
 var savedata;
+var lastMod;
 var noRecovery = false;
 
-
 try {// Load root from config file.  Error if missing or unable to determine api address
     var root = getRoot();
 } catch (e) {
@@ -47,7 +47,6 @@ if (templid !== null) {
 }
 
 $().ready(function () {// Once ready, load templates.
-
     // Add addditional templates here.  Specify template id, the template file, and the location
     log ('template id is ', templid);
     // Template for css.  Format cid-style.css
@@ -98,7 +97,7 @@ $().ready(function () {// Once ready, load templates.
                 $('#loginHeader').text(i18n.t('Please provide your encryption password'));
                 $('#Password').focus();
             }
-            var newGuest = templid = getURLParameter('newGuest');
+            var newGuest = getURLParameter('newGuest');
             if (newGuest) {
                 login();
             }
@@ -267,6 +266,7 @@ function login() {
                 return;
             }
             noRecovery = data.settings.noRecovery;
+            lastMod = data.lastMod;
             if (data.auth.length > 20) {
                 okLogin(data, action);
                 return;
@@ -295,7 +295,7 @@ function okLogin(data, action) {
         rKeys(data);
         return;
     }
-    settings = data.settings;
+    if (data.settings) settings = data.settings;
     itemid = getURLParameter("email");
     if (itemid === null) {
         $('.back').remove(); // remove back button if PGPManage only option
@@ -422,7 +422,11 @@ function firstPassChange() {
 }
 
 function showChangepass() {
-    view('NewPassword');
+    if (lastMod === 'null') {
+        showChangeFirstPassword();
+    } else {
+        view('NewPassword');
+    }
 }
 
 function showWait() {
@@ -550,6 +554,7 @@ function firstChangePass() {
             log('success ', data);
             if (data.auth.length > 20) {
                 auth = data.auth;
+                lastMod = 'now';
                 sessionID = data.sessionID;
                 $('#new1').val('');
                 $('#new2').val('');
@@ -657,20 +662,7 @@ function openreader(ldata, extra) {
             if (lastMod === 'null') {
                 log('for changepass');
                 window.setTimeout(function () {
-                    $('#Reader').css("position", "fixed");
-                    if((navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i))) {
-                        $('.passchange').css('height', '100%').css('width', '100%').css('margin-top', '0%')
-                        .bind('touchstart', function (e) {
-                            if (e.target.type !== 'password' && e.target.type !== 'text') {
-                                document.activeElement.blur();
-                            }
-                        });
-                    }
-                    $('#firstChangePassDiv').show();
-                    if (noRecovery) {
-                        $('.qaDiv').hide();
-                        $('.passchange').css('height', '50%').css('min-height', '400px');
-                    }
+                    showChangeFirstPassword();
                 },2000);
             }
             // Make all name columns same size.  Check for largest
@@ -711,6 +703,23 @@ function openreader(ldata, extra) {
 
 }
 
+function showChangeFirstPassword () {
+    $('#Reader').css("position", "fixed");
+    if((navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i))) {
+        $('.passchange').css('height', '100%').css('width', '100%').css('margin-top', '0%')
+        .bind('touchstart', function (e) {
+            if (e.target.type !== 'password' && e.target.type !== 'text') {
+                document.activeElement.blur();
+            }
+        });
+    }
+    $('#firstChangePassDiv').show();
+    if (noRecovery) {
+        $('.qaDiv').hide();
+        $('.passchange').css('height', '50%').css('min-height', '400px');
+    }
+}
+
 function getSignature (data) {
     var signedicon = '';
     if (data.results) {
@@ -741,15 +750,15 @@ function fail(alerttype)
 }
 
 function replace_content_id (content, data, item) {
-    content = content.replace(/cid:[^@]+@GUARD/g, function (c) {
+    content = content.replace(/src="cid:[^"]+/g, function (c) {
         var params = '&email=' + item +
         '&session=' + sessionID +
         "&userid=" + userid +
         "&cid=" + cid +
         '&auth=' + encodeURIComponent(auth) +
         '&lang=' + language +
-        '&content_id=' + encodeURIComponent(c.substring(4));
-        var link = getFullRoot() + 'oxguard/guest?action=getattachcid' + params;
+        '&content_id=' + encodeURIComponent(c.substring(9));
+        var link = "src=\"" + getFullRoot() + 'oxguard/guest?action=getattachcid' + params;
 
         return (link);
     });
